summaryrefslogtreecommitdiffstats
path: root/ksquirrel/sq_slideshow.ui.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-03 01:36:58 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-03 01:36:58 +0000
commitd9d0ac84a2b1609ff81b399b81842a15704cbefd (patch)
tree58c783db373c4633201e5a9716901599c1afad92 /ksquirrel/sq_slideshow.ui.h
parent63f270d62c4541f1379f0f82f5255a34e5037e00 (diff)
downloadksquirrel-d9d0ac84a2b1609ff81b399b81842a15704cbefd.tar.gz
ksquirrel-d9d0ac84a2b1609ff81b399b81842a15704cbefd.zip
TQt4 port ksquirrel
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ksquirrel@1239132 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksquirrel/sq_slideshow.ui.h')
-rw-r--r--ksquirrel/sq_slideshow.ui.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/ksquirrel/sq_slideshow.ui.h b/ksquirrel/sq_slideshow.ui.h
index 9a9119b..f70c48e 100644
--- a/ksquirrel/sq_slideshow.ui.h
+++ b/ksquirrel/sq_slideshow.ui.h
@@ -2,7 +2,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/
@@ -26,19 +26,19 @@ void SQ_SlideShow::init()
checkSize->setChecked(SQ_Config::instance()->readBoolEntry("messages_size", false));
checkPos->setChecked(SQ_Config::instance()->readBoolEntry("messages_pos", true));
- QColor col;
+ TQColor col;
col.setNamedColor(SQ_Config::instance()->readEntry("background", "#4e4e4e"));
bcolor->setColor(col);
col.setNamedColor(SQ_Config::instance()->readEntry("message_text", "#ffffff"));
tcolor->setColor(col);
- QPopupMenu *hist = new QPopupMenu;
+ TQPopupMenu *hist = new TQPopupMenu;
items = SQ_Config::instance()->readListEntry("history");
int i = 0;
setPath(items.last());
- for(QStringList::iterator it = items.begin();it != items.end();++it)
+ for(TQStringList::iterator it = items.begin();it != items.end();++it)
{
if(i++ < SQ_HIST_NUMBER)
hist->insertItem(*it);
@@ -46,16 +46,16 @@ void SQ_SlideShow::init()
break;
}
- connect(hist, SIGNAL(activated(int)), this, SLOT(slotActivated(int)));
+ connect(hist, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotActivated(int)));
pushHistory->setPopup(hist);
}
-int SQ_SlideShow::exec(QString &path)
+int SQ_SlideShow::exec(TQString &path)
{
- int result = QDialog::exec();
+ int result = TQDialog::exec();
- if(result == QDialog::Accepted)
+ if(result == TQDialog::Accepted)
{
// save parameters
SQ_Config::instance()->setGroup("Slideshow");
@@ -75,28 +75,28 @@ int SQ_SlideShow::exec(QString &path)
return result;
}
-void SQ_SlideShow::slotDirectory(const QString &dir)
+void SQ_SlideShow::slotDirectory(const TQString &dir)
{
if(!dir.isEmpty())
appendPath(dir);
}
-void SQ_SlideShow::setPath(const QString &path)
+void SQ_SlideShow::setPath(const TQString &path)
{
kurl->setURL(path);
}
void SQ_SlideShow::slotActivated(int id)
{
- QString dir = pushHistory->popup()->text(id);
+ TQString dir = pushHistory->popup()->text(id);
if(!dir.isEmpty())
setPath(dir);
}
-void SQ_SlideShow::appendPath(const QString &path)
+void SQ_SlideShow::appendPath(const TQString &path)
{
- if(items.findIndex(path) == -1)
+ if(items.tqfindIndex(path) == -1)
{
items.append(path);
pushHistory->popup()->insertItem(path);
@@ -108,7 +108,7 @@ void SQ_SlideShow::appendPath(const QString &path)
void SQ_SlideShow::slotCurrent()
{
- QString path = SQ_WidgetStack::instance()->url().prettyURL();
+ TQString path = SQ_WidgetStack::instance()->url().prettyURL();
setPath(path);
appendPath(path);
@@ -2,7 +2,7 @@
**
** If you wish to add, delete or rename functions or slots use
-** Qt Designer which will update this file, preserving your code. Create an
+** TQt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.